@@ -270,6 +270,7 @@ def pull_dataset(
         )
     except Unauthenticated:
         _error(f"please re-authenticate")
+
     try:
         release: Release = dataset.get_release(version)
         dataset.pull(release=release, only_annotations=only_annotations, use_folders=folders, video_frames=video_frames)
@@ -284,6 +285,7 @@ def pull_dataset(
             f"Version '{dataset.identifier}:{version}' is of format '{uef.format}', "
             f"only the darwin format ('json') is supported for `darwin dataset pull`"
         )
+
     print(f"Dataset {release.identifier} downloaded at {dataset.local_path}. ")
 
 
@@ -351,7 +353,7 @@ def list_remote_datasets(all_teams: bool, team: Optional[str] = None) -> None:
         datasets = list(client.list_remote_datasets())
 
     for dataset in datasets:
-        table.add_row(f"{dataset.team}/{dataset.slug}", str(dataset.image_count), f"{dataset.progress * 100:.1f}%")
+        table.add_row(f"{dataset.team}/{dataset.slug}", str(dataset.item_count), f"{dataset.progress * 100:.1f}%")
     if table.row_count == 0:
         print("No dataset available.")
     else:
@@ -633,8 +635,8 @@ def _has_valid_status(status: str) -> bool:
 
 
 def set_file_status(dataset_slug: str, status: str, files: List[str]) -> None:
-    if status not in ["archived", "restore-archived"]:
-        _error(f"Invalid status '{status}', available statuses: archived, restore-archived")
+    if status not in ["archived", "clear", "new", "restore-archived"]:
+        _error(f"Invalid status '{status}', available statuses: archived, clear, new, restore-archived")
 
     client: Client = _load_client(dataset_identifier=dataset_slug)
     try:
@@ -642,12 +644,36 @@ def set_file_status(dataset_slug: str, status: str, files: List[str]) -> None:
         items: Iterator[DatasetItem] = dataset.fetch_remote_files({"filenames": ",".join(files)})
         if status == "archived":
             dataset.archive(items)
+        elif status == "clear":
+            dataset.reset(items)
+        elif status == "new":
+            dataset.move_to_new(items)
         elif status == "restore-archived":
             dataset.restore_archived(items)
     except NotFound as e:
         _error(f"No dataset with name '{e.name}'")
 
 
+def delete_files(dataset_slug: str, files: List[str], skip_user_confirmation: bool = False) -> None:
+    client: Client = _load_client(dataset_identifier=dataset_slug)
+    try:
+        console = Console()
+        dataset: RemoteDataset = client.get_remote_dataset(dataset_identifier=dataset_slug)
+        items: Iterator[DatasetItem] = dataset.fetch_remote_files({"filenames": ",".join(files)})
+        if not skip_user_confirmation and not secure_continue_request():
+            console.print("Cancelled.")
+            return
+
+        with console.status("[bold red]Deleting files..."):
+            dataset.delete_items(items)
+            console.print("[bold green]Files successfully deleted!")
+
+    except NotFound as e:
+        _error(f"No dataset with name '{e.name}'")
+    except:
+        _error(f"An error has occurred, please try again later.")
+
+
 def find_import_supported_format(query: str, supported_formats: List[ImporterFormat],) -> ImportParser:
     for (fmt, fmt_parser) in supported_formats:
         if fmt == query:
