@@ -61,20 +61,24 @@ class Client:
 
         response: requests.Response = requests.get(urljoin(self.url, endpoint), headers=self._get_headers(team))
 
+        if debug:
+            print(
+                f"Client get request response ({response.json()}) with unexpected status "
+                f"({response.status_code}). "
+                f"Client: ({self})"
+                f"Request: (endpoint={endpoint})"
+            )
+
         if response.status_code == 401:
             raise Unauthorized()
+
         if response.status_code == 404:
             raise NotFound(urljoin(self.url, endpoint))
+
         if response.status_code != 200 and retry:
-            if debug:
-                print(
-                    f"Client get request response ({response.json()}) with unexpected status "
-                    f"({response.status_code}). "
-                    f"Client: ({self})"
-                    f"Request: (endpoint={endpoint})"
-                )
             time.sleep(10)
             return self.get(endpoint=endpoint, retry=False)
+
         if raw:
             return response
         else:
@@ -114,6 +118,14 @@ class Client:
             urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team)
         )
 
+        if debug:
+            print(
+                f"Client GET request got response ({response.json()}) with unexpected status "
+                f"({response.status_code}). "
+                f"Client: ({self})"
+                f"Request: (endpoint={endpoint}, payload={payload})"
+            )
+
         if response.status_code == 401:
             raise Unauthorized()
 
@@ -123,14 +135,6 @@ class Client:
                 raise InsufficientStorage()
 
         if response.status_code != 200 and retry:
-            if debug:
-                print(
-                    f"Client GET request got response ({response.json()}) with unexpected status "
-                    f"({response.status_code}). "
-                    f"Client: ({self})"
-                    f"Request: (endpoint={endpoint}, payload={payload})"
-                )
-
             time.sleep(10)
             return self.put(endpoint, payload=payload, retry=False)
 
@@ -177,20 +181,24 @@ class Client:
             urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team)
         )
 
+        if debug:
+            print(
+                f"Client get request response ({response.json()}) with unexpected status "
+                f"({response.status_code}). "
+                f"Client: ({self})"
+                f"Request: (endpoint={endpoint}, payload={payload})"
+            )
+
         if response.status_code == 401:
             raise Unauthorized()
 
+        if not error_handlers and not retry:
+            response.raise_for_status()
+
         if response.status_code != 200:
             for error_handler in error_handlers:
                 error_handler(response.status_code, response.json())
 
-            if debug:
-                print(
-                    f"Client get request response ({response.json()}) with unexpected status "
-                    f"({response.status_code}). "
-                    f"Client: ({self})"
-                    f"Request: (endpoint={endpoint}, payload={payload})"
-                )
             if retry:
                 time.sleep(10)
                 return self.post(endpoint, payload=payload, retry=False)
@@ -200,6 +208,7 @@ class Client:
     def delete(
         self,
         endpoint: str,
+        payload: Optional[Dict[Any, Any]] = None,
         team: Optional[str] = None,
         retry: bool = False,
         error_handlers: Optional[List[ErrorHandler]] = None,
@@ -210,11 +219,15 @@ class Client:
         Parameters
         ----------
         endpoint : str
-            Recipient of the HTTP operation
+            Recipient of the HTTP operation.
+        payload : Optional[Dict[Any, Any]]
+            JSON-encoded extra information that might be necessary to perform the deletion.
+        team : Optional[str]
+            Optional team slug, used to build the request headers.
         retry : bool
             Retry to perform the operation. Set to False on recursive calls.
-        refresh : bool
-            Flag for use the refresh token instead
+        error_handlers : Optional[List[ErrorHandler]]
+            List of functions to be called should the requests be unsuccessful.
         debug : bool
             Debugging flag. In this case failed requests get printed
 
@@ -223,28 +236,36 @@ class Client:
         dict
         Dictionary which contains the server response
         """
+        if payload is None:
+            payload = {}
         if error_handlers is None:
             error_handlers = []
 
-        response: requests.Response = requests.delete(urljoin(self.url, endpoint), headers=self._get_headers(team))
+        response: requests.Response = requests.delete(
+            urljoin(self.url, endpoint), json=payload, headers=self._get_headers(team)
+        )
+
+        if debug:
+            print(
+                f"Client get request response ({response.json()}) with unexpected status "
+                f"({response.status_code}). "
+                f"Client: ({self})"
+                f"Request: (endpoint={endpoint})"
+            )
 
         if response.status_code == 401:
             raise Unauthorized()
 
+        if not error_handlers and not retry:
+            response.raise_for_status()
+
         if response.status_code != 200:
             for error_handler in error_handlers:
                 error_handler(response.status_code, response.json())
 
-            if debug:
-                print(
-                    f"Client get request response ({response.json()}) with unexpected status "
-                    f"({response.status_code}). "
-                    f"Client: ({self})"
-                    f"Request: (endpoint={endpoint})"
-                )
             if retry:
                 time.sleep(10)
-                return self.delete(endpoint, retry=False)
+                return self.delete(endpoint, payload=payload, retry=False)
 
         return self._decode_response(response, debug)
 
@@ -287,7 +308,7 @@ class Client:
                 slug=dataset["slug"],
                 team=team or self.default_team,
                 dataset_id=dataset["id"],
-                image_count=dataset["num_images"],
+                item_count=dataset["num_images"] + dataset["num_videos"],
                 progress=dataset["progress"],
                 client=self,
             )
@@ -333,7 +354,7 @@ class Client:
                 slug=dataset["slug"],
                 team=parsed_dataset_identifier.team_slug,
                 dataset_id=dataset["id"],
-                image_count=dataset["num_images"],
+                item_count=dataset["num_images"] + dataset["num_videos"],
                 progress=0,
                 client=self,
             )
@@ -360,7 +381,7 @@ class Client:
             team=team or self.default_team,
             slug=dataset["slug"],
             dataset_id=dataset["id"],
-            image_count=dataset["num_images"],
+            item_count=dataset["num_images"],
             progress=0,
             client=self,
         )
