@@ -1,11 +1,12 @@
 import json
 import multiprocessing as mp
 from pathlib import Path
-from typing import Collection, List, Optional
+from typing import Any, Dict, Iterator, List, Optional, Tuple
 
 import numpy as np
 from darwin.dataset.utils import get_classes, get_release_path, load_pil_image
 from darwin.utils import SUPPORTED_IMAGE_EXTENSIONS
+from PIL import Image as PILImage
 
 
 class LocalDataset(object):
@@ -63,24 +64,7 @@ class LocalDataset(object):
         )
         self.num_classes = len(self.classes)
 
-        # Get the list of stems
-        if partition:
-            # Get the split
-            if split_type == "random":
-                split_file = f"{split_type}_{partition}.txt"
-            elif split_type == "stratified":
-                split_file = f"{split_type}_{annotation_type}_{partition}.txt"
-            split_path = release_path / "lists" / split / split_file
-            if split_path.is_file():
-                stems = (e.strip() for e in split_path.open())
-            else:
-                raise FileNotFoundError(
-                    f"could not find a dataset partition. "
-                    f"Split the dataset using `split_dataset()` from `darwin.dataset.split_manager`"
-                ) from None
-        else:
-            # If the partition is not specified, get all the annotations
-            stems = (e.relative_to(annotations_dir).parent / e.stem for e in annotations_dir.glob("**/*.json"))
+        stems = build_stems(release_path, annotations_dir, annotation_type, split, partition, split_type)
 
         # Find all the annotations and their corresponding images
         for stem in stems:
@@ -103,16 +87,16 @@ class LocalDataset(object):
 
         assert len(self.images_path) == len(self.annotations_path)
 
-    def get_img_info(self, index: int):
+    def get_img_info(self, index: int) -> Dict[str, Any]:
         with self.annotations_path[index].open() as f:
             data = json.load(f)["image"]
             return data
 
-    def get_height_and_width(self, index: int):
-        data = self.get_img_info(index)
+    def get_height_and_width(self, index: int) -> Tuple[float, float]:
+        data: Dict[str, Any] = self.get_img_info(index)
         return data["height"], data["width"]
 
-    def extend(self, dataset, extend_classes: bool = False):
+    def extend(self, dataset: "LocalDataset", extend_classes: bool = False) -> "LocalDataset":
         """Extends the current dataset with another one
 
         Parameters
@@ -143,13 +127,13 @@ class LocalDataset(object):
         self.annotations_path += dataset.annotations_path
         return self
 
-    def get_image(self, index: int):
+    def get_image(self, index: int) -> PILImage.Image:
         return load_pil_image(self.images_path[index])
 
-    def get_image_path(self, index: int):
+    def get_image_path(self, index: int) -> Path:
         return self.images_path[index]
 
-    def parse_json(self, index: int):
+    def parse_json(self, index: int) -> Dict[str, Any]:
         """
         Load an annotation and filter out the extra classes according to what
         specified in `self.classes` and the annotation_type
@@ -178,7 +162,7 @@ class LocalDataset(object):
             "annotations": annotations,
         }
 
-    def measure_mean_std(self, multi_threaded: bool = True):
+    def measure_mean_std(self, multi_threaded: bool = True) -> Tuple[np.ndarray, np.ndarray]:
         """Computes mean and std of train images, given the train loader
 
         Parameters
@@ -230,7 +214,7 @@ class LocalDataset(object):
         raise NotImplementedError("Base class Dataset does not have an implementation for this")
 
     @staticmethod
-    def _compute_weights(labels: Collection):
+    def _compute_weights(labels: List[int]) -> np.ndarray:
         """Given an array of labels computes the weights normalized
 
         Parameters
@@ -243,7 +227,7 @@ class LocalDataset(object):
         ndarray[float]
             Array of weights (one for each unique class) which are the inverse of their frequency
         """
-        class_support = np.unique(labels, return_counts=True)[1]
+        class_support: np.ndarray = np.unique(labels, return_counts=True)[1]
         class_frequencies = class_support / len(labels)
         # Class weights are the inverse of the class frequencies
         class_weights = 1 / class_frequencies
@@ -253,14 +237,14 @@ class LocalDataset(object):
 
     # Loads an image with Pillow and returns the channel wise means of the image.
     @staticmethod
-    def _return_mean(image_path):
+    def _return_mean(image_path: Path) -> np.ndarray:
         img = np.array(load_pil_image(image_path))
         mean = np.array([np.mean(img[:, :, 0]), np.mean(img[:, :, 1]), np.mean(img[:, :, 2])])
         return mean / 255.0
 
     # Loads an image with OpenCV and returns the channel wise std of the image.
     @staticmethod
-    def _return_std(image_path, mean):
+    def _return_std(image_path: Path, mean: np.ndarray) -> Tuple[np.ndarray, float]:
         img = np.array(load_pil_image(image_path)) / 255.0
         m2 = np.square(np.array([img[:, :, 0] - mean[0], img[:, :, 1] - mean[1], img[:, :, 2] - mean[2]]))
         return np.sum(np.sum(m2, axis=1), 1), m2.size / 3.0
@@ -280,3 +264,38 @@ class LocalDataset(object):
             f"  Number of images: {len(self.images_path)}\n"
             f"  Number of classes: {len(self.classes)}"
         )
+
+
+def build_stems(
+    release_path: Path,
+    annotations_dir: Path,
+    annotation_type: str,
+    split: str,
+    partition: Optional[str] = None,
+    split_type: str = "random",
+) -> Iterator[str]:
+    # If no partition is specified, then take all json files in the annotations directory.
+    # The resulting generator prepends parent directories relative to the main annotation directory.
+    #
+    # E.g.: ["annotations/test/1.json", "annotations/2.json", "annotations/test/2/3.json"]:
+    #     - annotations/test/1
+    #     - annotations/2
+    #     - annotations/test/2/3
+    if partition is None:
+        return (str(e.relative_to(annotations_dir).parent / e.stem) for e in annotations_dir.glob("**/*.json"))
+
+    if split_type == "random":
+        split_filename = f"{split_type}_{partition}.txt"
+    elif split_type == "stratified":
+        split_filename = f"{split_type}_{annotation_type}_{partition}.txt"
+    else:
+        raise ValueError(f'Unknown split type "{split_type}"')
+
+    split_path = release_path / "lists" / split / split_filename
+    if split_path.is_file():
+        return (e.strip("\n\r") for e in split_path.open())
+
+    raise FileNotFoundError(
+        f"could not find a dataset partition. "
+        f"Split the dataset using `split_dataset()` from `darwin.dataset.split_manager`"
+    )
