@@ -59,7 +59,7 @@ class RemoteDataset:
         name: str,
         slug: str,
         dataset_id: int,
-        image_count: int = 0,
+        item_count: int = 0,
         progress: float = 0,
     ):
         """
@@ -78,8 +78,8 @@ class RemoteDataset:
             spaces are replaced by dashes, e.g., `bird-species`. This string is unique within a team
         dataset_id : int
             Unique internal reference from the Darwin backend
-        image_count : int
-            Dataset size (number of images)
+        item_count : int
+            Dataset size (number of items)
         progress : float
             How much of the dataset has been annotated 0.0 to 1.0 (1.0 == 100%)
         client : Client
@@ -89,7 +89,7 @@ class RemoteDataset:
         self.name = name
         self.slug = slug or name
         self.dataset_id = dataset_id
-        self.image_count = image_count
+        self.item_count = item_count
         self.progress = progress
         self.client = client
         self.annotation_types: Optional[List[Dict[str, Any]]] = None
@@ -376,14 +376,29 @@ class RemoteDataset:
                 return
 
     def archive(self, items: Iterator[DatasetItem]) -> None:
-        self.client.put(
-            f"datasets/{self.dataset_id}/items/archive", {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        )
+        endpoint: str = f"teams/{self.team}/datasets/{self.slug}/items/archive"
+        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
+        self.client.put(endpoint, payload)
 
     def restore_archived(self, items: Iterator[DatasetItem]) -> None:
-        self.client.put(
-            f"datasets/{self.dataset_id}/items/restore", {"filter": {"dataset_item_ids": [item.id for item in items]}}
-        )
+        endpoint: str = f"teams/{self.team}/datasets/{self.slug}/items/restore"
+        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
+        self.client.put(endpoint, payload)
+
+    def move_to_new(self, items: Iterator[DatasetItem]) -> None:
+        endpoint: str = f"teams/{self.team}/datasets/{self.slug}/items/move_to_new"
+        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
+        self.client.put(endpoint, payload)
+
+    def reset(self, items: Iterator[DatasetItem]) -> None:
+        endpoint: str = f"teams/{self.team}/datasets/{self.slug}/items/reset"
+        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
+        self.client.put(endpoint, payload)
+
+    def delete_items(self, items: Iterator[DatasetItem]) -> None:
+        endpoint: str = f"teams/{self.team}/datasets/{self.slug}/items"
+        payload: Dict[str, Any] = {"filter": {"dataset_item_ids": [item.id for item in items]}}
+        self.client.delete(endpoint, payload)
 
     def fetch_annotation_type_id_for_name(self, name: str) -> Optional[int]:
         """
@@ -631,8 +646,8 @@ class RemoteDataset:
 
     def split(
         self,
-        val_percentage: float = 0.1,
-        test_percentage: float = 0,
+        val_percentage: int = 10,
+        test_percentage: int = 0,
         split_seed: int = 0,
         make_default_split: bool = True,
         release_name: Optional[str] = None,
@@ -643,9 +658,9 @@ class RemoteDataset:
 
         Parameters
         ----------
-        val_percentage : float
+        val_percentage : int
             Percentage of images used in the validation set
-        test_percentage : float
+        test_percentage : int
             Percentage of images used in the test set
         force_resplit : bool
             Discard previous split and create a new one
