@@ -1,6 +1,6 @@
 import json
 from pathlib import Path
-from typing import Optional
+from typing import Any, Dict, Optional
 
 import darwin.datatypes as dt
 
@@ -17,14 +17,14 @@ def parse_file(path: Path) -> Optional[dt.AnnotationFile]:
         )
 
 
-def _remove_leading_slash(filename):
+def _remove_leading_slash(filename: str) -> str:
     if filename[0] == "/":
         return filename[1:]
     else:
         return filename
 
 
-def _parse_annotation(annotation):
+def _parse_annotation(annotation: Dict[str, Any]) -> Optional[dt.Annotation]:
     annotation_type = annotation["type"]
     annotation_label = annotation["label"]
     if annotation_type not in ["box", "class"]:
@@ -35,7 +35,8 @@ def _parse_annotation(annotation):
 
     # Class is metadata that we can ignore
     if annotation_type == "class":
-        return
+        return None
+
     if annotation_type == "box":
         coords = annotation["coordinates"]
         x1, y1 = coords[0]["x"], coords[0]["y"]
